@@ -1,5 +1,5 @@
 package Git::Raw::Filter::List;
-$Git::Raw::Filter::List::VERSION = '0.88';
+$Git::Raw::Filter::List::VERSION = '0.90';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Git::Raw::Filter::List - Git filter list class
 
 =head1 VERSION
 
-version 0.88
+version 0.90
 
 =head1 DESCRIPTION
 
@@ -44,7 +44,7 @@ containing the filtered content.
 
 =head1 AUTHOR
 
-Jacques Germishuys <jacquesg@striata.com>
+Jacques Germishuys <jacquesg@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
