@@ -1,5 +1,5 @@
 package Git::Raw::Submodule;
-$Git::Raw::Submodule::VERSION = '0.88';
+$Git::Raw::Submodule::VERSION = '0.90';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Git::Raw::Submodule - Git submodule class
 
 =head1 VERSION
 
-version 0.88
+version 0.90
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,7 @@ Reread submodule info from config, index, and HEAD.
 
 =head1 AUTHOR
 
-Jacques Germishuys <jacquesg@striata.com>
+Jacques Germishuys <jacquesg@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
